@@ -18,7 +18,7 @@
 */
 
 #include <config.h>
-#include <sys/stat.h>
+#include "lstat.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -73,6 +73,14 @@ unsigned long dev_ino_hash_2 (void const *key);
 int dev_ino_hash_compare (void const *x, void const *y);
 int symlink_ancestry (struct file_link *flink);
 
+#ifndef HAVE_LSTAT
+#undef lstat
+int lstat(const char *filename, struct stat *sbuf)
+{
+  return stat(filename, sbuf);
+}
+#endif /* !HAVE_LSTAT */
+
 #if HAVE_LINK
 
 struct file_link *find_alias_link (struct file_link *flink, struct stat *stp);
@@ -185,7 +193,13 @@ walk_flink (struct file_link *flink, struct dynvec *sub_dirs_vec)
   flink->fl_flags = (old_flags & ~(FL_TYPE_MASK|FL_SYM_LINK)) | new_flags;
   if (FL_IS_DIR (new_flags))
     {
-      struct file_link *alias_link = find_alias_link (flink, &st);
+
+      struct file_link *alias_link;
+#if HAVE_LINK
+      alias_link = find_alias_link (flink, &st);
+#else
+      alias_link = 0;
+#endif /* HAVE_LINK */
 
       if (alias_link)
 	{
